@@ -12,7 +12,9 @@ js_compressed = Signal(providing_args=["package", "version"])
 
 @receiver(css_compressed)
 @receiver(js_compressed)
-def invalidate_cache(sender, package, version, **kwargs):
+def invalidate_cache(sender, package, version, bust_cache=False, **kwargs):
     filename_base, filename = os.path.split(package['output'])
-    cache.set("pipeline:%s" % filename, str(version),
-        settings.PIPELINE_CACHE_TIMEOUT)
+    if bust_cache:
+        print "bust_cache"
+        cache.set("pipeline:%s" % filename, str(version),
+            settings.PIPELINE_CACHE_TIMEOUT)
